Release v0.0.8
---------------------------

- fix: fix chat command

Release v0.0.7 (2023-03-07)
---------------------------

- feat:  add `review` command, now you can review your code changes by using `ai review` command
- feat:  handle rate limit errors and retry

Release v0.0.6 (2023-03-06)
---------------------------

- feat: support multi-line input, to enable it, use `ai setting --edit multi_line_input=yes`
- feat: `setting` command now supports `--edit` option example: `setting --edit api_key=xxx raw=yes`

Release v0.0.5 (2023-03-05)
---------------------------

## [Update] - 2023-03-05

- feat: add `setting` command. now you can save settings to a file
